from setuptools import find_packages, setup
setup(
    name='sinever',
    version='1.0.0',
    description='a test for dist on pypi',
    author='sinever',
    author_email='sinever@126.com',
    url='https://openeuler.org',
)